using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace TetrisOnlineLauncher
{
    public partial class FormMain : Form
    {
        private string configFile = "TetrisOnlineLauncher.cfg";
        private bool optionsToggle = false;

        public FormMain()
        {
            InitializeComponent();
        }

        private void bStart_Click(object sender, EventArgs e)
        {
            Start();
        }

        private void Start()
        {
            Cursor = Cursors.WaitCursor;

            try
            {
                Launcher l = new Launcher();
                l.Auth(tbID.Text, tbPassword.Text);

                if (cbSkip.Checked)
                    l.StartTetrisExe();
                else
                {
                    if (!File.Exists("PatchClient.exe"))
                    {
                        if (MessageBox.Show(this, String.Format("Do you want to install Tetris Online in this folder:\n{0} ?",
                                new DirectoryInfo(".").FullName), "", MessageBoxButtons.YesNo) == DialogResult.Yes)
                            l.DownloadPatchClient();
                        else
                            throw new SilentException();
                    }

                    l.StartPatchClient();
                }

                SaveConfig();
                Close();
            }
            catch (SilentException ex)
            {

            }
            catch (Exception ex)
            {
                MessageBox.Show(this, ex.Message);
            }

            Cursor = Cursors.Default;
        }

        private void bExit_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void SaveConfig()
        {
            try
            {
                StreamWriter sw = new StreamWriter(configFile);

                if (rRemID.Checked || rRemIDPass.Checked || rAutoLogin.Checked)
                    sw.WriteLine(tbID.Text);
                else
                    sw.WriteLine();

                if (rRemIDPass.Checked || rAutoLogin.Checked)
                    sw.WriteLine(tbPassword.Text);
                else
                    sw.WriteLine();

                if (rRemIDPass.Checked)
                    sw.WriteLine(2);
                else if (rRemID.Checked)
                    sw.WriteLine(1);
                else if (rAutoLogin.Checked)
                    sw.WriteLine(3);
                else // (rRemNothing.Checked)
                    sw.WriteLine(0);

                sw.WriteLine(cbSkip.Checked);

                sw.Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(this, ex.Message);
            }
        }

        private void ReadConfig()
        {
            try
            {
                StreamReader sr = new StreamReader(configFile);

                tbID.Text = sr.ReadLine();
                tbPassword.Text = sr.ReadLine();

                int rem = int.Parse(sr.ReadLine());

                if (rem == 2)
                    rRemIDPass.Checked = true;
                else if (rem == 1)
                    rRemID.Checked = true;
                else if (rem == 3)
                    rAutoLogin.Checked = true;
                else if (rem == 0)
                    rRemNothing.Checked = true;
                else
                    throw new Exception("Invalid value");

                cbSkip.Checked = bool.Parse(sr.ReadLine());

                sr.Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(this, ex.Message);
            }
        }

        private void FormMain_Load(object sender, EventArgs e)
        {
            if (File.Exists(configFile))
                ReadConfig();

            if (tbID.Text == "")
                (tbID as Control).Select();
            else
                (tbPassword as Control).Select();

            if (!File.Exists("tetris.exe"))
            {
                cbSkip.Checked = false;
                cbSkip.Enabled = false;
            }

            ShowHideOptions();

            if (rAutoLogin.Checked)
                Start();
        }

        private void bOptions_Click(object sender, EventArgs e)
        {
            optionsToggle = !optionsToggle;
            ShowHideOptions();
        }

        private void ShowHideOptions()
        {
            if (optionsToggle)
                ClientSize = new Size(ClientSize.Width, cbSkip.Bottom + 15);
            else
                ClientSize = new Size(ClientSize.Width, bOptions.Bottom + 15);

            gbRemember.Visible = optionsToggle;
            cbSkip.Visible = optionsToggle;
        }

        private void rAutoLogin_Click(object sender, EventArgs e)
        {
            if (rAutoLogin.Checked)
                MessageBox.Show(this, String.Format("You wont see login screen again. To disable auto login in future you will have to delete {0} or edit it manually.", configFile));
        }

        private void bRegister_Click(object sender, EventArgs e)
        {
            FormRegister fRegister = new FormRegister();

            DialogResult res = fRegister.ShowDialog();

            if (res == DialogResult.OK)
            {
                tbID.Text = fRegister.ID;
                tbPassword.Text = fRegister.PW;
            }
        }
    }
}